aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/lazy/SkBitmapFactory.h
diff options
context:
space:
mode:
authorGravatar reed@google.com <reed@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-11-01 13:46:54 +0000
committerGravatar reed@google.com <reed@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-11-01 13:46:54 +0000
commit2bd8b8100529c96c81c30f749f672f4caf775b04 (patch)
tree5a7468a4570ecf07a7089afbfbfeebb5c773555c /include/lazy/SkBitmapFactory.h
parent05d56ebbf385c8723c9bed3409739055afa3b073 (diff)
move SkImage::ColorType into SkColorType
objective -- move clients over to SkImage tasks - use SkImageInfo instead of SkBitmap::Config - add support for colortables to SkImage - add drawImage to SkCanvas - return SkImage from readPixels This CL works towards the first task R=robertphillips@google.com Review URL: https://codereview.chromium.org/54363008 git-svn-id: http://skia.googlecode.com/svn/trunk@12077 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/lazy/SkBitmapFactory.h')
-rw-r--r--include/lazy/SkBitmapFactory.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/lazy/SkBitmapFactory.h b/include/lazy/SkBitmapFactory.h
index e967a915b2..8a39a48a28 100644
--- a/include/lazy/SkBitmapFactory.h
+++ b/include/lazy/SkBitmapFactory.h
@@ -39,7 +39,7 @@ public:
/**
* Signature for a function to decode an image from encoded data.
*/
- typedef bool (*DecodeProc)(const void* data, size_t length, SkImage::Info*, const Target*);
+ typedef bool (*DecodeProc)(const void* data, size_t length, SkImageInfo*, const Target*);
/**
* Create a bitmap factory which uses DecodeProc for decoding.
@@ -67,18 +67,18 @@ public:
bool installPixelRef(SkData*, SkBitmap*);
/**
* An object for selecting an SkImageCache to use based on an SkImage::Info.
*/
class CacheSelector : public SkRefCnt {
public:
SK_DECLARE_INST_COUNT(CacheSelector)
/**
* Return an SkImageCache to use based on the provided SkImage::Info. If the caller decides
* to hang on to the result, it will call ref, so the implementation should not add a ref
* as a result of this call.
*/
- virtual SkImageCache* selectCache(const SkImage::Info&) = 0;
+ virtual SkImageCache* selectCache(const SkImageInfo&) = 0;
private:
typedef SkRefCnt INHERITED;
@@ -67,18 +67,18 @@ public:
bool installPixelRef(SkData*, SkBitmap*);
/**
- * An object for selecting an SkImageCache to use based on an SkImage::Info.
+ * An object for selecting an SkImageCache to use based on an SkImageInfo.
*/
class CacheSelector : public SkRefCnt {
@@ -67,18 +67,18 @@ public:
SK_DECLARE_INST_COUNT(CacheSelector)
/**
- * Return an SkImageCache to use based on the provided SkImage::Info. If the caller decides
+ * Return an SkImageCache to use based on the provided SkImageInfo. If the caller decides
* to hang on to the result, it will call ref, so the implementation should not add a ref
* as a result of this call.